<?php
/*
Plugin Name: Audio and Video Comments
Plugin URI: 
Description: Adds a Flash based audio & video comment system to WordPress comments. Let your readers leave video comments on your posts.
Version: 1.3
Author: Sergey Weinberg
Author URI: http://www.commentt.com/
*/

/**
 * README
 * 
 * This plugin works by inserting a Flash Comment Recorder above the Comments
 * form. When a reader records a comment successfully, the Flash app calls a 
 * javascript function called commentSaved() and passes as one variable, the 
 * necessary flashvars to be included in the Flash Player app for that comment.
 * 
 * In addition to inserting the Flash Comment Recorder, we also add a javascript
 * function called commentSaved to handle this callback. That function writes 
 * the flashvars data to a hidden input field which is submitted when the user
 * posts the comment.
 * 
 * Then we add an action on submit of a comment to grab that hidden input and 
 * insert a code into the body of the comment. We then add a filter to replace 
 * the code with the Flash Player on display of the comment.
 */

define('WPFC_PLUGIN_NAME','WP Flash Comments');
define('WPFC_OPTIONS_PAGE','Flash Comments');
define('WPFC_MANAGEMENT_PAGE','Flash Comments');
define('WPFC_DEBUG',FALSE);

/**
 * Tasks
 * 
 * @todo Add options page to configure all options
 * @todo Add additional options to the wpfc_globals array
 */

// Let's define some functions...

function wpfc_init() {
	
	// Let's make the plugin globals available
	global $wpfc_globals;
	
	// Let's get the options and make them available
	$wpfc_options_raw = get_option('wpfc_options');
	
	// Did we get anything back?
	if ($wpfc_options_raw != "") {
		
		// Unserialize the data
		$wpfc_globals = unserialize($wpfc_options_raw);
		
	}
	// The data wasn't found
	else {
		
		// Set the default values
		$wpfc_globals['userid'] = 'b54d4e8f3fc1192d51c1a77a9ee3a9a5';
		
		$wpfc_globals['left'] = '-95px';
		$wpfc_globals['top'] = '-190px';
		$wpfc_globals['popup_header'] = "Leave a Flash Comment";
		$wpfc_globals['popup_text'] = "<p>To leave an audio or video comment, simply record it below and then once you've finished recording, click close.</p>\n<p><strong>Note:</strong> You must submit a text comment after recording your audio or video comment and the recording will be added automatically to your comment.</p>";
		$wpfc_globals['popup_bg_col'] = "#E6E6FA";
		$wpfc_globals['popup_border_col'] = "#000000";
		
		$wpfc_globals['text_close'] = "Close Flash Comment Recorder";
		$wpfc_globals['text_open'] = "Open Flash Comment Recorder";
		$wpfc_globals['text_confirm'] = "Your flash comment has been recorded, now enter a text comment and save.";
		
		$wpfc_globals['recorder_url'] = "http://www.commentt.com:1050/red5/PlayerRecorder.swf";
		
		// Store these
		add_option('wpfc_options',serialize($wpfc_globals),'Options for the ' . WPFC_PLUGIN_NAME . 'plugin.');
		
	}
	
}

function wpfc_comment_form() {
	
	// Let's make the global settings available
	global $wpfc_globals;
	
	// If this function has already been run, return now
	if (WPFC_COMMENT_FORM_OUTPUT === TRUE) {
		return;
	}
	
	// Define a global constant to ensure we don't output the form twice
	define('WPFC_COMMENT_FORM_OUTPUT',TRUE);
	
	// Add the Flash Recorder and javascript function
	?>

<script type="text/javascript">
function commentSaved(url,flashvars) {
	document.getElementById('wpfc_url').value = url;
	document.getElementById('wpfc_flashvars').value = flashvars;
	document.getElementById('wpfc_comment_form').style.visibility = 'hidden';
	document.getElementById('wpfc_confirm').innerHTML = '<?php _e($wpfc_globals['text_confirm']); ?>';
	return false;
}
function wpfc_close() {
	document.getElementById('wpfc_comment_form').style.visibility = 'hidden';
	return false;
}
function wpfc_open() {
	document.getElementById('wpfc_comment_form').style.visibility = 'visible';
	return false;
}
</script>
<input type="hidden" name="wpfc_flashvars" id="wpfc_flashvars">
<input type="hidden" name="wpfc_url" id="wpfc_url">
<div class="wpfc_centre" style="position: relative;">
<div id="wpfc_comment_form" style="text-align: left; position: absolute; top: <?php print($wpfc_globals['top']); ?>; left: <?php print($wpfc_globals['left']); ?>; width: 650px; height: 310px; background-color: <?php print($wpfc_globals['popup_bg_col']); ?>; border: 1px solid <?php print($wpfc_globals['popup_border_col']); ?>; visibility: hidden;"><div class="wpfc_pad10" style="padding: 10px;">
<div id="wpfc_recorder" style="float: right; margin-left: 10px;"><embed src="<?php print($wpfc_globals['recorder_url']); ?>" loop="false" quality="high" bgcolor="#ffffff" wmode="transparent" allowScriptAccess="always" width="360" height="290" type="application/x-shockwave-flash" pluginspage="http://www.macromedia.com/go/getflashplayer" flashvars="uid=<?php print($wpfc_globals['userid']); ?>&recordMode=true&automaticPost=true" /></div>
<h3><?php _e($wpfc_globals['popup_header']); ?></h3>
<?php _e($wpfc_globals['popup_text']); ?>
<p><a href="<?php print ($_SERVER['PHP_SELF'] . "?" . $_SERVER['QUERY_STRING']); ?>" onclick="if(wpfc_close()) return false; else return false;"><?php _e($wpfc_globals['text_close']); ?></a></p>
<?php if(WPFC_DEBUG == TRUE) { ?><p><a href="<?php print ($_SERVER['PHP_SELF'] . "?" . $_SERVER['QUERY_STRING']); ?>" onclick="if(commentSaved('http://www.commentt.com:1050/red5/PlayerRecorder.swf','uid=e32bd13e2add097461cb96824b7a829c&topicId=0359242d4834835fa865be756294b8d1&recordMode=true')) return false; else return false;">Simulate Save</a></p><?php } ?>
</div></div>
</div>
<p id="wpfc_confirm"><a href="<?php print ($_SERVER['PHP_SELF'] . "?" . $_SERVER['QUERY_STRING']); ?>" onclick="if(wpfc_open()) return false; else return false;"><?php _e($wpfc_globals['text_open']); ?></a></p>
<?php
	
}

function wpfc_comment_post($wpfc_comment_ID) {
	
	// Let's make the wpdb class available
	global $wpdb;
	
	// Was a flash comment submitted?
	if (isset($_POST['wpfc_flashvars']) && $_POST['wpfc_flashvars'] != "") {
		
		// Update the post
		if ($wpdb->query("UPDATE `" . $wpdb->comments . "` SET comment_content = CONCAT('[[wpfc_comment:::" . $wpdb->escape($_POST['wpfc_url']) . ":::" . $wpdb->escape($_POST['wpfc_flashvars']) . "]]',comment_content) WHERE comment_ID = '" . $wpfc_comment_ID . "' LIMIT 1") === FALSE) {
			// Can we output some type of error message? Where would it go?
		}
		
	}
	
}

function wpfc_admin_menu() {
	
	// Let's register a new page
	if (function_exists('add_options_page')) {
		add_options_page(__(WPFC_OPTIONS_PAGE),__(WPFC_OPTIONS_PAGE),'manage_options',__FILE__,'wpfc_options_page');
	}
	
	// and another one...
	if (function_exists('add_management_page')) {
		add_management_page(__(WPFC_MANAGEMENT_PAGE),__(WPFC_MANAGEMENT_PAGE),'moderate_comments',__FILE__,'wpfc_management_page');
	}
	
}

function wpfc_options_page() {
	
	// Let's make the db class available
	global $wpdb;
	// Now let's also make the plugin globals available
	global $wpfc_globals;
	
	// Do we need to update the options?
	if (isset($_POST['wpfc_action']) && $_POST['wpfc_action'] == "update-options") {
		
		if (!get_magic_quotes_gpc()) {
			foreach ($_POST as $key => $val) {
				$_POST[$key] = stripslashes($val);
			}
		}
		
		// Let's first set the options
		$wpfc_globals['userid'] = $_POST['wpfc_userid'];
		
		$wpfc_globals['left'] = $_POST['wpfc_left'];
		$wpfc_globals['top'] = $_POST['wpfc_top'];
		$wpfc_globals['popup_header'] = $_POST['wpfc_popup_header'];
		$wpfc_globals['popup_text'] = $_POST['wpfc_popup_text'];
		$wpfc_globals['popup_bg_col'] = $_POST['wpfc_popup_bg_col'];
		$wpfc_globals['popup_border_col'] = $_POST['wpfc_popup_border_col'];
		
		$wpfc_globals['text_close'] = $_POST['wpfc_text_close'];
		$wpfc_globals['text_open'] = $_POST['wpfc_text_open'];
		$wpfc_globals['text_confirm'] = $_POST['wpfc_text_confirm'];
		
		$wpfc_globals['recorder_url'] = $_POST['wpfc_recorder_url'];
		
		// Save the changes
		update_option('wpfc_options',serialize($wpfc_globals));
		
	}
	
	// Let's whip up some code to set the options...
	?>
<div class="wrap">
<h2><?php _e(WPFC_OPTIONS_PAGE); ?></h2>
<form method="POST" action="<?php print($_SERVER['PHP_SELF'] . "?page=" . $_REQUEST['page']); ?>">

<input type="hidden" name="wpfc_action" id="wpfc_action" value="update-options">

<p class="submit"><input type="submit" name="Submit" value="<?php _e('Update Options &raquo;') ?>" /></p>

<fieldset class="options">
<legend><?php _e('User ID'); ?></legend>
<table class="optiontable">
	<tr valign="top"> 
		<th scope="row"><?php _e('User ID:') ?></th> 
		<td><input name="wpfc_userid" type="text" id="wpfc_userid" value="<?php print($wpfc_globals['userid']); ?>" size="40" />
			<br />
			<?php _e('Enter the user id you were given during registration here.'); ?></td> 
	</tr>
</table>
</fieldset>
	
<fieldset class="options">
<legend><?php _e('Popup Options'); ?></legend>
<table class="optiontable">
	<tr valign="top"> 
		<th scope="row"><?php _e('Position Left:') ?></th> 
		<td><input name="wpfc_left" type="text" id="wpfc_left" value="<?php print($wpfc_globals['left']); ?>" size="5" />
			<br />
			<?php _e('This controls the left to right position of the popup from the point where it is inserted on the comment form. Experiment with different values here until you find a position that works for your theme.'); ?></td> 
	</tr>
	<tr valign="top"> 
		<th scope="row"><?php _e('Position Top:') ?></th> 
		<td><input name="wpfc_top" type="text" id="wpfc_top" value="<?php print($wpfc_globals['top']); ?>" size="5" />
			<br />
			<?php _e('This controls the top to bottom position of the popup, as above.'); ?></td> 
	</tr>
	<tr valign="top"> 
		<th scope="row"><?php _e('Header:') ?></th> 
		<td><input name="wpfc_popup_header" type="text" id="wpfc_popup_header" value="<?php print($wpfc_globals['popup_header']); ?>" size="40" />
			<br />
			<?php _e('This is the header text that appears within the popup.'); ?></td> 
	</tr>
	<tr valign="top"> 
		<th scope="row"><?php _e('Popup Text:') ?></th> 
		<td><textarea name="wpfc_popup_text" id="wpfc_popup_text" rows="5" cols="50" style="width: 97%;"><?php print($wpfc_globals['popup_text']); ?></textarea>
			<br />
			<?php _e('This is the text that appears within the popup. HTML is allowed.'); ?></td> 
	</tr>
	<tr valign="top"> 
		<th scope="row"><?php _e('Backround Colour:') ?></th> 
		<td><input name="wpfc_popup_bg_col" type="text" id="wpfc_popup_bg_col" value="<?php print($wpfc_globals['popup_bg_col']); ?>" size="8" />
			<br />
			<?php _e('This is the background colour of the popup as an HTML colour.'); ?></td> 
	</tr>
	<tr valign="top"> 
		<th scope="row"><?php _e('Border Colour:') ?></th> 
		<td><input name="wpfc_popup_border_col" type="text" id="wpfc_popup_border_col" value="<?php print($wpfc_globals['popup_border_col']); ?>" size="8" />
			<br />
			<?php _e('This is the popup border colour as an HTML colour.'); ?></td> 
	</tr>
</table>
</fieldset>

<fieldset class="options">
<legend><?php _e('Link Text'); ?></legend>
<table class="optiontable">
	<tr valign="top"> 
		<th scope="row"><?php _e('Close Popup:') ?></th> 
		<td><input name="wpfc_text_close" type="text" id="wpfc_text_close" value="<?php print($wpfc_globals['text_close']); ?>" size="40" />
			<br />
			<?php _e('This text appears under the body in the popup and allows the user to close the popup without leaving a Flash comment.'); ?></td> 
	</tr>
	<tr valign="top"> 
		<th scope="row"><?php _e('Open Popup:') ?></th> 
		<td><input name="wpfc_text_open" type="text" id="wpfc_text_open" value="<?php print($wpfc_globals['text_open']); ?>" size="40" />
			<br />
			<?php _e('If the user initially clicks the close button without leaving a comment, this text is displayed giving them the option to go back and leave a Flash comment.'); ?></td> 
	</tr>
	<tr valign="top"> 
		<th scope="row"><?php _e('Comment Saved Confirmation:') ?></th> 
		<td><input name="wpfc_text_confirm" type="text" id="wpfc_text_confirm" value="<?php print($wpfc_globals['text_confirm']); ?>" size="40" />
			<br />
			<?php _e('When a user leaves a comment this text replaces the Open Popup text, confirming their comment has been submitted.'); ?></td> 
	</tr>
</table>
</fieldset>

<fieldset class="options">
<legend><?php _e('Flash Variables'); ?></legend>
<table class="optiontable">
	<tr valign="top"> 
		<th scope="row"><?php _e('Recorder URL:') ?></th> 
		<td><input name="wpfc_recorder_url" type="text" id="wpfc_recorder_url" style="width: 95%" value="<?php print($wpfc_globals['recorder_url']); ?>" size="45" />
			<br />
			<?php _e('This is the URL of the Flash recorder. The default option is probably correct.'); ?></td> 
	</tr>
<?php /*	<tr valign="top"> 
		<th scope="row"><?php _e('Recorder Flashvars:') ?></th> 
		<td><input name="wpfc_recorder_flashvars" type="text" id="wpfc_recorder_flashvars" style="width: 95%" value="<?php print($wpfc_globals['recorder_flashvars']); ?>" size="45" />
			<br />
			<?php _e('This is the content of the &quot;flashvars&quot; variable passed to the Flash recorder. The default option is probably correct.'); ?></td> 
	</tr> */ ?>
</table>
</fieldset>

<p class="submit"><input type="submit" name="Submit" value="<?php _e('Update Options &raquo;') ?>" /></p>

</form>
</div>
	<?php
	
}

function wpfc_management_page() {
	
	// Let's whip out some HTML
	
	
}

function wpfc_get_comment_text($wpfc_comment_text) {
	
	// Check if the code is set, if it is, replace with the player
	
	// Does this comment have a flash comment?
	if (substr($wpfc_comment_text,0,17) == "[[wpfc_comment:::") {
		
		// Where is the closing ]] tag?
		$wpfc_end = strpos($wpfc_comment_text,']]') + 2;
		
		// Let's grab the code out of the comment...
		$wpfc_rawvars = substr($wpfc_comment_text,17,$wpfc_end-19);
		
		// Let's now split this into the url and flashvars
		$wpfc_vars = explode(":::",$wpfc_rawvars);
		
		// Strip out the wpfc_comment tag from the content body
		$wpfc_comment_text = substr($wpfc_comment_text,$wpfc_end);
		
		// Now let's add the EMBED tag with the flashvars
		$wpfc_comment_text = '<p class="wpfc_comment_player"><embed src="' . $wpfc_vars[0] . '" loop="false" quality="high" bgcolor="#ffffff" wmode="transparent" allowScriptAccess="always" width="360" height="290" type="application/x-shockwave-flash" pluginspage="http://www.macromedia.com/go/getflashplayer" flashvars="' . $wpfc_vars[1] . '" /></p>' . "\n\n" . $wpfc_comment_text;
		
	}
	
	return $wpfc_comment_text;
	
}

// Let's add some actions & filters
add_action('init','wpfc_init');
add_action('comment_form','wpfc_comment_form');
add_action('comment_post','wpfc_comment_post');
add_action('admin_menu','wpfc_admin_menu');
add_filter('get_comment_text','wpfc_get_comment_text');

?>